@@ -3,48 +3,47 @@ Pipeline and chaining elements.
 """
 import logging
 import os
-
-# from abc import ABC, abstractmethod
-from typing import List, Union
-from pathlib import Path, PosixPath
+import re
 import traceback
 from copy import copy
-
 from itertools import groupby
-import re
-import h5py
-
-# import yaml
-from tqdm import tqdm
+from pathlib import Path, PosixPath
 
 # from p_tqdm import p_map
 from time import perf_counter
-from pathos.multiprocessing import Pool
 
+# from abc import ABC, abstractmethod
+from typing import Union
+
+import h5py
 import numpy as np
+from agora.abc import ParametersABC, ProcessABC
+from agora.io.metadata import MetaData, parse_logfiles
+from agora.io.reader import StateReader
+from agora.io.signal import Signal
+from agora.io.writer import (  # BabyWriter,
+    LinearBabyWriter,
+    StateWriter,
+    TilerWriter,
+)
+from pathos.multiprocessing import Pool
+from postprocessor.core.processor import PostProcessor, PostProcessorParameters
 
 # import pandas as pd
 from scipy import ndimage
 
-from agora.io.metadata import MetaData
+# import yaml
+from tqdm import tqdm
+
+from aliby.baby_client import BabyParameters, BabyRunner
 from aliby.haystack import initialise_tf
-from aliby.baby_client import BabyRunner, BabyParameters
-from aliby.tile.tiler import Tiler, TilerParameters
 from aliby.io.dataset import Dataset, DatasetLocal
-from aliby.io.image import Image, ImageLocal
-from agora.abc import ParametersABC, ProcessABC
-from agora.io.writer import (
-    TilerWriter,
-    BabyWriter,
-    StateWriter,
-    LinearBabyWriter,
-)
-from agora.io.reader import StateReader
-from agora.io.signal import Signal
+from aliby.io.image import get_image_class
+from aliby.tile.tiler import Tiler, TilerParameters
 from extraction.core.extractor import Extractor, ExtractorParameters
 from extraction.core.functions.defaults import exparams_from_meta
-from postprocessor.core.processor import PostProcessor, PostProcessorParameters
-from postprocessor.compiler import ExperimentCompiler, PageOrganiser
+
+# from postprocessor.compiler import ExperimentCompiler, PageOrganiser
 
 logging.basicConfig(
     filename="aliby.log",
@@ -73,7 +72,7 @@ class PipelineParameters(ParametersABC):
         baby={},
         extraction={},
         postprocessing={},
-        reporting={},
+        # reporting={},
     ):
         """
         Load unit test experiment
@@ -138,8 +137,11 @@ class PipelineParameters(ParametersABC):
                 defaults["general"][k] = v
 
         defaults["tiler"] = TilerParameters.default(**tiler).to_dict()
-        defaults["baby"] = BabyParameters.default(**extraction).to_dict()
-        defaults["extraction"] = exparams_from_meta(meta)
+        defaults["baby"] = BabyParameters.default(**baby).to_dict()
+        defaults["extraction"] = (
+            exparams_from_meta(meta)
+            or BabyParameters.default(**extraction).to_dict()
+        )
         defaults["postprocessing"] = PostProcessorParameters.default(
             **postprocessing
         ).to_dict()
@@ -293,7 +295,7 @@ class Pipeline(ProcessABC):
         def filt_int(d: dict, filt: int):
             return {k: v for i, (k, v) in enumerate(d.items()) if i == filt}
 
-        def filt_str(d: dict, filt: str):
+        def filt_str(image_ids: dict, filt: str):
             return {k: v for k, v in image_ids.items() if re.search(filt, k)}
 
         def pick_filter(image_ids: dict, filt: Union[int, str]):
@@ -362,7 +364,7 @@ class Pipeline(ProcessABC):
             # Set up
             directory = general_config["directory"]
 
-            image_wrapper = ImageLocal if isinstance(image_id, str) else Image
+            image_wrapper = get_image_class(image_id)
 
             with image_wrapper(
                 image_id, **self.general.get("server_info", {})
@@ -520,10 +522,9 @@ class Pipeline(ProcessABC):
                         exparams, store=filename, tiler=steps["tiler"]
                     )
 
-                # RUN
+                # START PIPELINE
                 # Adjust tps based on how many tps are available on the server
                 frac_clogged_traps = 0
-                # print(f"Processing from {process_from}")
                 min_process_from = min(process_from.values())
                 pbar = tqdm(
                     range(min_process_from, tps),
@@ -564,7 +565,7 @@ class Pipeline(ProcessABC):
 
                                 # Step-specific actions
 
-                                if step=='tiler':
+                                if step == "tiler":
                                     if i == min_process_from:
                                         print(
                                             f"Found {steps['tiler'].n_traps} traps in {image.name}"
@@ -594,7 +595,6 @@ class Pipeline(ProcessABC):
                                     for k in ["masks", "labels"]:
                                         run_kwargs[step][k] = None
 
-
                         frac_clogged_traps = self.check_earlystop(
                             filename, earlystop, steps["tiler"].tile_size
                         )
