@@ -135,7 +135,7 @@ class remoteImageViewer:
         return self.cells.random_valid_trap_tp(
             min_ncells=min_ncells,
             min_consecutive_tps=min_consecutive_tps,
-            label_modulo=label_modulo,
+            # label_modulo=label_modulo,
         )
 
     def get_entire_position(self):
